==> camel-k-sources-2.0.0.tar.gz: camel-k-2.0.0/e2e/install/kustomize/setup_test.go <==
//go:build integration
// +build integration

// To enable compilation of this file in Goland, go to "Settings -> Go -> Vendoring & Build Tags -> Custom Tags" and add "integration"

/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package kustomize

import (
	"fmt"
	"os"
	"testing"

	. "github.com/apache/camel-k/v2/e2e/support"
	testutil "github.com/apache/camel-k/v2/e2e/support/util"
	. "github.com/onsi/gomega"
)

func TestSetupKustomizeBasic(t *testing.T) {
	RegisterTestingT(t)
	makeDir := testutil.MakeTempCopyDir(t, "../../../install")
	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)

	// Ensure no CRDs are already installed
	UninstallAll()
	Eventually(CRDs()).Should(HaveLen(0))

	// Return the cluster to previous state
	defer Cleanup()

	WithNewTestNamespace(t, func(ns string) {
		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
		ExpectExecSucceed(t, Make("setup-cluster", namespaceArg))
		Eventually(CRDs()).Should(HaveLen(ExpectedCRDs))

		ExpectExecSucceed(t, Make("setup", namespaceArg))

		kpRoles := ExpectedKubePromoteRoles
		opRoles := kpRoles + ExpectedOSPromoteRoles
		Eventually(Role(ns)).Should(Or(HaveLen(kpRoles), HaveLen(opRoles)))

		kcRoles := ExpectedKubeClusterRoles
		ocRoles := kcRoles + ExpectedOSClusterRoles
		Eventually(ClusterRole()).Should(Or(HaveLen(kcRoles), HaveLen(ocRoles)))

		// Tidy up to ensure next test works
		Expect(Kamel("uninstall", "-n", ns).Execute()).To(Succeed())
	})

}

func TestSetupKustomizeGlobal(t *testing.T) {
	makeDir := testutil.MakeTempCopyDir(t, "../../../install")
	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)

	// Ensure no CRDs are already installed
	UninstallAll()
	Eventually(CRDs()).Should(HaveLen(0))

	// Return the cluster to previous state
	defer Cleanup()

	WithNewTestNamespace(t, func(ns string) {
		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
		ExpectExecSucceed(t, Make("setup-cluster", namespaceArg))
		Eventually(CRDs()).Should(HaveLen(ExpectedCRDs))

		ExpectExecSucceed(t, Make("setup", "GLOBAL=true", namespaceArg))

		Eventually(Role(ns)).Should(HaveLen(0))

		kcpRoles := ExpectedKubeClusterRoles + ExpectedKubePromoteRoles
		ocpRoles := kcpRoles + ExpectedOSClusterRoles + ExpectedOSPromoteRoles
		Eventually(ClusterRole()).Should(Or(HaveLen(kcpRoles), HaveLen(ocpRoles)))
	})
}

==> camel-k-sources-2.3.3.tar.gz: camel-k-2.3.3/e2e/install/kustomize/setup_test.go <==
//go:build integration
// +build integration

// To enable compilation of this file in Goland, go to "Settings -> Go -> Vendoring & Build Tags -> Custom Tags" and add "integration"

/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package kustomize

import (
	"context"
	"fmt"
	"os"
	"testing"

	. "github.com/apache/camel-k/v2/e2e/support"
	testutil "github.com/apache/camel-k/v2/e2e/support/util"
	"github.com/apache/camel-k/v2/pkg/util/defaults"
	. "github.com/onsi/gomega"
)

func TestSetupKustomizeBasic(t *testing.T) {
	ctx := TestContext()
	g := NewWithT(t)
	makeDir := testutil.MakeTempCopyDir(t, "../../../install")
	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)

	// Ensure no CRDs are already installed
	g.Expect(UninstallAll(t, ctx)).To(Succeed())
	g.Eventually(CRDs(t)).Should(HaveLen(0))

	// Return the cluster to previous state
	defer Cleanup(t, ctx)

	WithNewTestNamespace(t, func(ctx context.Context, g *WithT, ns string) {
		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
		ExpectExecSucceed(t, g, Make(t, "setup-cluster", namespaceArg))
		g.Eventually(CRDs(t)).Should(HaveLen(GetExpectedCRDs(defaults.Version)))

		ExpectExecSucceed(t, g, Make(t, "setup", namespaceArg))

		kpRoles := ExpectedKubePromoteRoles
		opRoles := kpRoles + ExpectedOSPromoteRoles
		g.Eventually(Role(t, ctx, ns)).Should(Or(HaveLen(kpRoles), HaveLen(opRoles)))

		kcRoles := ExpectedKubeClusterRoles
		ocRoles := kcRoles + ExpectedOSClusterRoles
		g.Eventually(ClusterRole(t, ctx)).Should(Or(HaveLen(kcRoles), HaveLen(ocRoles)))

		// Tidy up to ensure next test works
		g.Expect(Kamel(t, ctx, "uninstall", "-n", ns).Execute()).To(Succeed())
	})

}

func TestSetupKustomizeGlobal(t *testing.T) {
	makeDir := testutil.MakeTempCopyDir(t, "../../../install")
	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)

	ctx := TestContext()

	// Ensure no CRDs are already installed
	g := NewWithT(t)
	g.Expect(UninstallAll(t, ctx)).To(Succeed())
	g.Eventually(CRDs(t)).Should(HaveLen(0))

	// Return the cluster to previous state
	defer Cleanup(t, ctx)

	WithNewTestNamespace(t, func(ctx context.Context, g *WithT, ns string) {
		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
		ExpectExecSucceed(t, g, Make(t, "setup-cluster", namespaceArg))
		g.Eventually(CRDs(t)).Should(HaveLen(GetExpectedCRDs(defaults.Version)))

		ExpectExecSucceed(t, g, Make(t, "setup", "GLOBAL=true", namespaceArg))

		g.Eventually(Role(t, ctx, ns)).Should(HaveLen(0))

		kcpRoles := ExpectedKubeClusterRoles + ExpectedKubePromoteRoles
		ocpRoles := kcpRoles + ExpectedOSClusterRoles + ExpectedOSPromoteRoles
		g.Eventually(ClusterRole(t, ctx)).Should(Or(HaveLen(kcpRoles), HaveLen(ocpRoles)))
	})
}
